==> ejc-sale-impl-3.0.0-20220404.055637-20-sources.jar: com/ejianc/business/sale/bean/SalesreconciliationEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 销售调账
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_salesreconciliation")
public class SalesreconciliationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="customer_id")
    private Long customerId; // 客户主键
    @TableField(value="customer_name")
    private String customerName; // 客户名称
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="product_id")
    private Long productId; // 产品主键
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="total_amount")
    private BigDecimal totalAmount; // 总金额
    @TableField(value="uncollected_amount")
    private BigDecimal uncollectedAmount; // 剩余未收金额
    @TableField(value="adjustment_amount")
    private BigDecimal adjustmentAmount; // 调账金额
    @TableField(value="adjustment_balance")
    private BigDecimal adjustmentBalance; // 调账余额
    @TableField(value="amount_after_adjustment")
    private BigDecimal amountAfterAdjustment; // 调账后金额
    @TableField(value="date")
    private Date date; // 业务发生所属日期
    @TableField(value="entry_date")
    private Date entryDate; // 录时间入
    @TableField(value="reason")
    private String reason; // 调账原因
    @TableField(value="profitcenter_id")
    private Long profitcenterId; // 利润中心主键
    @TableField(value="profitcenter_name")
    private String profitcenterName; // 利润中心名称
    @TableField(value="status")
    private Integer status; // 调账状态:1确认0未确认
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="distribution_moeny")
    private BigDecimal distributionMoeny; // 已勾金额
    @TableField(value="sign_id")
    private Long signId; // 签认单id
    
    
    

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public BigDecimal getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }
    public BigDecimal getUncollectedAmount() {
        return uncollectedAmount;
    }

    public void setUncollectedAmount(BigDecimal uncollectedAmount) {
        this.uncollectedAmount = uncollectedAmount;
    }
    public BigDecimal getAdjustmentAmount() {
        return adjustmentAmount;
    }

    public void setAdjustmentAmount(BigDecimal adjustmentAmount) {
        this.adjustmentAmount = adjustmentAmount;
    }
    public BigDecimal getAdjustmentBalance() {
        return adjustmentBalance;
    }

    public void setAdjustmentBalance(BigDecimal adjustmentBalance) {
        this.adjustmentBalance = adjustmentBalance;
    }
    public BigDecimal getAmountAfterAdjustment() {
        return amountAfterAdjustment;
    }

    public void setAmountAfterAdjustment(BigDecimal amountAfterAdjustment) {
        this.amountAfterAdjustment = amountAfterAdjustment;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public Date getEntryDate() {
        return entryDate;
    }

    public void setEntryDate(Date entryDate) {
        this.entryDate = entryDate;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public Long getProfitcenterId() {
        return profitcenterId;
    }

    public void setProfitcenterId(Long profitcenterId) {
        this.profitcenterId = profitcenterId;
    }
    public String getProfitcenterName() {
        return profitcenterName;
    }

    public void setProfitcenterName(String profitcenterName) {
        this.profitcenterName = profitcenterName;
    }
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public BigDecimal getDistributionMoeny() {
        return distributionMoeny;
    }

    public void setDistributionMoeny(BigDecimal distributionMoeny) {
        this.distributionMoeny = distributionMoeny;
    }

    public Long getSignId() {
        return signId;
    }

    public void setSignId(Long signId) {
        this.signId = signId;
    }
}

==> ejc-sale-impl-3.0.0-20220419.090228-47-sources.jar: com/ejianc/business/sale/bean/SalesreconciliationEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 销售调账
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_salesreconciliation")
public class SalesreconciliationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="customer_id")
    private Long customerId; // 客户主键
    @TableField(value="customer_name")
    private String customerName; // 客户名称
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="product_id")
    private Long productId; // 产品主键
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="total_amount")
    private BigDecimal totalAmount; // 总金额
    @TableField(value="uncollected_amount")
    private BigDecimal uncollectedAmount; // 剩余未收金额
    @TableField(value="adjustment_amount")
    private BigDecimal adjustmentAmount; // 调账金额
    @TableField(value="adjustment_balance")
    private BigDecimal adjustmentBalance; // 调账余额
    @TableField(value="amount_after_adjustment")
    private BigDecimal amountAfterAdjustment; // 调账后金额
    @TableField(value="date")
    private Date date; // 业务发生所属日期
    @TableField(value="entry_date")
    private Date entryDate; // 录时间入
    @TableField(value="reason")
    private String reason; // 调账原因
    @TableField(value="profitcenter_id")
    private Long profitcenterId; // 利润中心主键
    @TableField(value="profitcenter_name")
    private String profitcenterName; // 利润中心名称
    @TableField(value="status")
    private Integer status; // 调账状态:1确认0未确认2调账中
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="distribution_moeny")
    private BigDecimal distributionMoeny; // 已勾金额
    @TableField(value="sign_id")
    private Long signId; // 签认单id
    
    
    

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public BigDecimal getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }
    public BigDecimal getUncollectedAmount() {
        return uncollectedAmount;
    }

    public void setUncollectedAmount(BigDecimal uncollectedAmount) {
        this.uncollectedAmount = uncollectedAmount;
    }
    public BigDecimal getAdjustmentAmount() {
        return adjustmentAmount;
    }

    public void setAdjustmentAmount(BigDecimal adjustmentAmount) {
        this.adjustmentAmount = adjustmentAmount;
    }
    public BigDecimal getAdjustmentBalance() {
        return adjustmentBalance;
    }

    public void setAdjustmentBalance(BigDecimal adjustmentBalance) {
        this.adjustmentBalance = adjustmentBalance;
    }
    public BigDecimal getAmountAfterAdjustment() {
        return amountAfterAdjustment;
    }

    public void setAmountAfterAdjustment(BigDecimal amountAfterAdjustment) {
        this.amountAfterAdjustment = amountAfterAdjustment;
    }
    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }
    public Date getEntryDate() {
        return entryDate;
    }

    public void setEntryDate(Date entryDate) {
        this.entryDate = entryDate;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public Long getProfitcenterId() {
        return profitcenterId;
    }

    public void setProfitcenterId(Long profitcenterId) {
        this.profitcenterId = profitcenterId;
    }
    public String getProfitcenterName() {
        return profitcenterName;
    }

    public void setProfitcenterName(String profitcenterName) {
        this.profitcenterName = profitcenterName;
    }
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public BigDecimal getDistributionMoeny() {
        return distributionMoeny;
    }

    public void setDistributionMoeny(BigDecimal distributionMoeny) {
        this.distributionMoeny = distributionMoeny;
    }

    public Long getSignId() {
        return signId;
    }

    public void setSignId(Long signId) {
        this.signId = signId;
    }

}
